Learn R Programming

mnda (version 1.0.9)

p_val_rank: Calculate p.value for x given a null pdf using ranks

Description

Calculate p.value for x given a null pdf using ranks

Usage

p_val_rank(x, null.pdf, alternative = "two.sided")

Value

p.value

Arguments

x

numeric value

null.pdf

a numeric vector of null distribution samples

alternative

alterative test including: "two.sided" [default], "greater", and "less"

Examples

Run this code
p.val = p_val_rank(1, 1:100)

Run the code above in your browser using DataLab